/**
 *******************************************************************************
 * @file    main.c
 *
 * @brief   Main program body.
 *
 * @author  DPM
 *
 * @version V1.0.0
 *
 * @date    2024-5-6
 *
 *******************************************************************************/

/*
    Copyright (c) 2024, DP Microelectronics Inc.

    Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice, this
       list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
    3. Neither the name of the copyright holder nor the names of its contributors
       may be used to endorse or promote products derived from this software without
       specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
OF SUCH DAMAGE.
*/

/* Files include */
#include "main.h"
#include "dpm32m0xx.h"
#include "dpm32m0xx_eval.h"
#include "systick.h"
#include <stdio.h>


/**
  * @addtogroup DPM32M08X_LibSamples
  * @{
  */

/**
  * @addtogroup RCC
  * @{
  */

/**
  * @addtogroup RCC_LowPowerStop_GPIO
  * @{
  */

/* Private typedef --------------------------------------------------------------*/

/* Private define ---------------------------------------------------------------*/

/* Private macro ----------------------------------------------------------------*/

/* Private variables ------------------------------------------------------------*/

/* Private functions ------------------------------------------------------------*/

/**
  * @brief  The program entry function.
  * @retval int
  */
int main(void)
{
  for(uint32_t i = 0; i < 600000; i++)
  {
    __NOP();
  }
  
  /* Configure the system clock */
  SystemClockInit();
  
  /* LED Init */
  EVAL_LedInit(LED1);
  EVAL_LedInit(LED2);
  /* Print Uart Init */
  EVAL_ComInit();

  /********************* Operation  *********************/  
  /* Enable clock */
  RCC_Unlock();
  RCC_AHBPeriphClockCmd(RCC_AHB_PERIPH_GPIO, ENABLE);

  GPIO_InitTypeStruct GPIO_InitStruct;
  /* Config OUTPUT mode */
  GPIO_InitStruct.GPIO_Mode = GPIO_MODE_INPUT;
  GPIO_InitStruct.GPIO_Speed = GPIO_SPEED_HIGH;
  GPIO_InitStruct.GPIO_OType = GPIO_OTYPE_PP;
  GPIO_InitStruct.GPIO_PuPd = GPIO_PUPD_DOWN;
  GPIO_InitStruct.GPIO_Pin = GPIO_PIN_8;  
  /* Init GPIO PB10 */
  GPIO_Init(GPIOA, &GPIO_InitStruct);
  /* Config rising interrupt */;
  GPIO_IntConfig(GPIOA, GPIO_PIN_8, GPIO_INT_RISING);
  /* Enable interrupt */
  NVIC_SetPriority(GPIOA_IRQn, 2);
  NVIC_EnableIRQ(GPIOA_IRQn);
  GPIO_IntEnable(GPIOA, GPIO_PIN_8);  
  
  printf("Low power stop mode example \n");
  
  /* Infinite loop */
  while(1)
  {
    EVAL_LedOn(LED1);
    for(uint32_t i = 0; i < 600000; i++)
    {
      __NOP();
    }
    EVAL_LedOff(LED1);
        
    /* Enter stop mode */
    RCC_EnterLowPowerMode(RCC_LOW_POWER_MODE_STOP, RCC_LOW_POWER_ENTRY_WFI);
    
    EVAL_LedToggle(LED2);
    
    for(uint32_t i = 0; i < 1000000; i++)
    {
      __NOP();
    }

  }
}

/* retarget the C library printf function to the usart */
int fputc(int ch, FILE *f)
{
  UART_SendData(EVAL_COM0, (uint8_t)ch);

  while(RESET == UART_GetIntFlagStatus(EVAL_COM0, UART_INT_FLAG_TXE));

  return ch;
}


/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */

/************************ (C) COPYRIGHT DP *****END OF FILE ***************************/
